This module implements DbConnection to handle connections to a Microsoft SQL Server database
Summary
Functions
Creates a supervisor child specification for a pool of connections.
See start_link/2 for options.
Executes a query on a given connection. Returns {:ok, result} or {:error, reason}.
Starts and links to a database connection process.
By default the DBConnection starts a pool with a single connection.
The size of the pool can be increased with :pool_size. A separate
pool can be given with the :pool option.
Functions
Creates a supervisor child specification for a pool of connections.
See start_link/2 for options.
See DBConnection.close/3.
Prepare a query with a database connection for later execution.
It returns {:ok, query} on success or {:error, exception} if there was
an error.
The returned query can then be passed to execute/4 and/or close/3
Executes a query on a given connection. Returns {:ok, result} or {:error, reason}.
Starts and links to a database connection process.
By default the DBConnection starts a pool with a single connection.
The size of the pool can be increased with :pool_size. A separate
pool can be given with the :pool option.